Learn R Programming

itraxR (version 1.12.2)

CD166_19_S1: Itrax core scanner data for core CD166_19_S1

Description

A dataset containing XRF, optical and radiographic images and metadata for ocean core CD166_19_S1. This is a subset of a more complete dataset available.

Usage

CD166_19_S1

Arguments

Format

A list containing the following:

xrf

a tibble of scan variables

rgb

a list containing the optical image matrix and associated metadata

rad

a list containing the radiographic image matrix and associated metadata