Learn R Programming

itraxR (version 1.12.2)

itrax_munsell: Convert an Itrax Image File into Munsell Colour

Description

Reads a colour calibrated Itrax image file and processes it to estimate Munsell colour.

Usage

itrax_munsell(image, proportion = 0.1)

Value

a table of values

Arguments

image

defines the name of the image file imported using `itrax_image()`. It is essential that the image has been colour calibrated using a colour card or other method.

proportion

defines the width down the centre of the image to use for processing

Examples

Run this code
if (FALSE) {
itrax_image(file = system.file("extdata",
                              "CD166_19_S1_optical_lowres.tif",
                              package = "itraxR",
                              mustWork = TRUE),
           meta = system.file("extdata",
                              "CD166_19_S1_xrf_document.txt",
                              package = "itraxR",
                              mustWork = TRUE),
           plot = FALSE) %>%
 magrittr::extract2(1) %>%
 itrax_munsell() %>%
 dplyr::slice_sample(n = 10)
 }


Run the code above in your browser using DataLab