Performs and visualises principle component analysis data from Itrax result data
itrax_ordination(
dataframe,
elementsonly = TRUE,
zeros = "addone",
transform = TRUE,
return = "list",
plot = FALSE
)either an output of prcomp(), or a list including the input data
pass the name of a dataframe parsed using "itrax_import()" or "itrax_join()"
if TRUE, only chemical elements are included. If FALSE, the data is passed unfiltered, otherwise a character vector of desired variable names can be supplied
if "addone", adds one to all values. If "limit", replaces zero values with 0.001. Otherwise a function can be supplied to remove zero values.
binary operator that if TRUE will center-log-transform the data, if FALSE will leave the data untransformed. Otherwise, a function can be supplied to transform the data.
if "pca" the output of prcomp() is returned, otherwise "list" is a list including the transformed data, sample scores, and the output of prcomp().
set to true if a biplot is required as a side-effect
itrax_ordination(CD166_19_S1$xrf, plot = TRUE)
Run the code above in your browser using DataLab