Learn R Programming

itraxR (version 1.12.2)

itrax_radiograph: Read an Itrax Radiograph File

Description

Reads an Itrax radiograph file and trims it according to the metadata provided.

Usage

itrax_radiograph(
  file = "radiograph.tif",
  meta = "document.txt",
  plot = FALSE,
  trim = TRUE
)

Value

a matrix of RGB values, and the relevant data from the metadata file relating to the image. Also computes the aspect ratio of the image.

Arguments

file

defines the name of the datafile to parse

meta

defines the relating metadata

plot

would you like to create a plot as a side-effect?

trim

defines positions of the trim if required, input is a vector with min and max positions

Examples

Run this code
itrax_radiograph(file = system.file("extdata",
                         "CD166_19_S1_radiograph_adj.tif",
                         package = "itraxR",
                         mustWork = TRUE),
                 meta = system.file("extdata",
                         "CD166_19_S1_rad_document.txt",
                         package = "itraxR",
                         mustWork = TRUE),
                 plot = TRUE)

Run the code above in your browser using DataLab