Learn R Programming

itraxR (version 1.12.2)

itrax_restspectra: Make a spectrograph from raw Itrax data spectra files

Description

Parses a folder full of raw spectra files from an Itrax core scanner and produces a spectral graph of all the data by position

Usage

itrax_restspectra(
  foldername = "XRF data",
  parameters = "settings.dfl",
  datapos = 37,
  depthpos = 6,
  plot = TRUE,
  trans = "pseudo_log"
)

Value

a dataframe of all the spectral data

Arguments

foldername

defines the folder where the spectra "*.spe" files are located - or the path of the zipped folder where it is stored.

parameters

optionally, defines the Q-Spec settings file from which to calculate the channel energies

datapos

defines the row at which spectral data begins in the files

depthpos

defines the row at which depth data begins is located in the files

plot

TRUE/FALSE, selects whether to create a plot as a side-effect

trans

transformation applied in the plot - see `?ggplot2::scales_colour_gradient()` for options

Examples

Run this code
if (FALSE) itrax_restspectra("~/itraxBook/CD166_19_(2020)/CD166_19_S1/CD166_19_S1/XRF data")

Run the code above in your browser using DataLab