A dataset containing XRF, optical and radiographic images and metadata for ocean core CD166_19_S1. This is a subset of a more complete dataset available.
CD166_19_S1A list containing the following:
a tibble of scan variables
a list containing the optical image matrix and associated metadata
a list containing the radiographic image matrix and associated metadata